==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_fields/VERB_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for VERB_Type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="VERB_Type">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="Add"/>
 *     &lt;enumeration value="Get"/>
 *     &lt;enumeration value="Sync"/>
 *     &lt;enumeration value="Delete"/>
 *     &lt;enumeration value="Cancel"/>
 *     &lt;enumeration value="Change"/>
 *     &lt;enumeration value="Confirm"/>
 *     &lt;enumeration value="ConfirmRevert"/>
 *     &lt;enumeration value="ConfirmUpload"/>
 *     &lt;enumeration value="Copy"/>
 *     &lt;enumeration value="Create"/>
 *     &lt;enumeration value="Issue"/>
 *     &lt;enumeration value="Load"/>
 *     &lt;enumeration value="Receive"/>
 *     &lt;enumeration value="Transfer"/>
 *     &lt;enumeration value="Update"/>
 *     &lt;enumeration value="Deactivate"/>
 *     &lt;enumeration value="Approve"/>
 *     &lt;enumeration value="Remove"/>
 *     &lt;enumeration value="Revert"/>
 *     &lt;enumeration value="Replace"/>
 *     &lt;enumeration value="Move"/>
 *     &lt;enumeration value="Validate"/>
 *     &lt;enumeration value="Refresh"/>
 *     &lt;enumeration value="Save"/>
 *     &lt;enumeration value="Upload"/>
 *     &lt;enumeration value="Run"/>
 *     &lt;enumeration value="Download"/>
 *     &lt;enumeration value="GenerateAndRelease"/>
 *     &lt;enumeration value="Process"/>
 *     &lt;enumeration value="Retrieve"/>
 *     &lt;enumeration value="Unlink"/>
 *     &lt;enumeration value="Close"/>
 *     &lt;enumeration value="Assign"/>
 *     &lt;enumeration value="Generate"/>
 *     &lt;enumeration value="Purge"/>
 *     &lt;enumeration value="FreezeOrUnfreeze"/>
 *     &lt;enumeration value="Calculate"/>
 *     &lt;enumeration value="SaveAndValidate"/>
 *     &lt;enumeration value="Reject"/>
 *     &lt;enumeration value="Match"/>
 *     &lt;enumeration value="AddOrSync"/>
 *     &lt;enumeration value="Terminate"/>
 *     &lt;enumeration value="Print"/>
 *     &lt;enumeration value="Associate"/>
 *     &lt;enumeration value="Disassociate"/>
 *     &lt;enumeration value="Regenerate"/>
 *     &lt;enumeration value="Logon"/>
 *     &lt;enumeration value="Logoff"/>
 *     &lt;enumeration value="Prepare"/>
 *     &lt;enumeration value="Search"/>
 *     &lt;enumeration value="Import"/>
 *     &lt;enumeration value="Start"/>
 *     &lt;enumeration value="Stop"/>
 *     &lt;enumeration value="Export"/>
 *     &lt;enumeration value="Init"/>
 *     &lt;enumeration value="ActivateOrDeactivate"/>
 *     &lt;enumeration value="Select"/>
 *     &lt;enumeration value="Undo"/>
 *     &lt;enumeration value="UndoAll"/>
 *     &lt;enumeration value="RedoAll"/>
 *     &lt;enumeration value="ApproveSingle"/>
 *     &lt;enumeration value="UndoCancel"/>
 *     &lt;enumeration value="Reallocate"/>
 *     &lt;enumeration value="Award"/>
 *     &lt;enumeration value="Resequence"/>
 *     &lt;enumeration value="List"/>
 *     &lt;enumeration value="ValidateAndAdd"/>
 *     &lt;enumeration value="SelectAll"/>
 *     &lt;enumeration value="Unlock"/>
 *     &lt;enumeration value="Activate"/>
 *     &lt;enumeration value="Reset"/>
 *     &lt;enumeration value="BatchCopy"/>
 *     &lt;enumeration value="BatchDelete"/>
 *     &lt;enumeration value="Review"/>
 *     &lt;enumeration value="Extend"/>
 *     &lt;enumeration value="SignOff"/>
 *     &lt;enumeration value="Isolate"/>
 *     &lt;enumeration value="Deisolate"/>
 *     &lt;enumeration value="Perform"/>
 *     &lt;enumeration value="Complete"/>
 *     &lt;enumeration value="SetDefault"/>
 *     &lt;enumeration value="Detach"/>
 *     &lt;enumeration value="RetrieveSingle"/>
 *     &lt;enumeration value="Recalculate"/>
 *     &lt;enumeration value="Quote"/>
 *     &lt;enumeration value="Exclude"/>
 *     &lt;enumeration value="Revoke"/>
 *     &lt;enumeration value="Lock"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "VERB_Type")
@XmlEnum
public enum VERB_Type {

    @XmlEnumValue("Add")
    ADD("Add"),
    @XmlEnumValue("Get")
    GET("Get"),
    @XmlEnumValue("Sync")
    SYNC("Sync"),
    @XmlEnumValue("Delete")
    DELETE("Delete"),
    @XmlEnumValue("Cancel")
    CANCEL("Cancel"),
    @XmlEnumValue("Change")
    CHANGE("Change"),
    @XmlEnumValue("Confirm")
    CONFIRM("Confirm"),
    @XmlEnumValue("ConfirmRevert")
    CONFIRM_REVERT("ConfirmRevert"),
    @XmlEnumValue("ConfirmUpload")
    CONFIRM_UPLOAD("ConfirmUpload"),
    @XmlEnumValue("Copy")
    COPY("Copy"),
    @XmlEnumValue("Create")
    CREATE("Create"),
    @XmlEnumValue("Issue")
    ISSUE("Issue"),
    @XmlEnumValue("Load")
    LOAD("Load"),
    @XmlEnumValue("Receive")
    RECEIVE("Receive"),
    @XmlEnumValue("Transfer")
    TRANSFER("Transfer"),
    @XmlEnumValue("Update")
    UPDATE("Update"),
    @XmlEnumValue("Deactivate")
    DEACTIVATE("Deactivate"),
    @XmlEnumValue("Approve")
    APPROVE("Approve"),
    @XmlEnumValue("Remove")
    REMOVE("Remove"),
    @XmlEnumValue("Revert")
    REVERT("Revert"),
    @XmlEnumValue("Replace")
    REPLACE("Replace"),
    @XmlEnumValue("Move")
    MOVE("Move"),
    @XmlEnumValue("Validate")
    VALIDATE("Validate"),
    @XmlEnumValue("Refresh")
    REFRESH("Refresh"),
    @XmlEnumValue("Save")
    SAVE("Save"),
    @XmlEnumValue("Upload")
    UPLOAD("Upload"),
    @XmlEnumValue("Run")
    RUN("Run"),
    @XmlEnumValue("Download")
    DOWNLOAD("Download"),
    @XmlEnumValue("GenerateAndRelease")
    GENERATE_AND_RELEASE("GenerateAndRelease"),
    @XmlEnumValue("Process")
    PROCESS("Process"),
    @XmlEnumValue("Retrieve")
    RETRIEVE("Retrieve"),
    @XmlEnumValue("Unlink")
    UNLINK("Unlink"),
    @XmlEnumValue("Close")
    CLOSE("Close"),
    @XmlEnumValue("Assign")
    ASSIGN("Assign"),
    @XmlEnumValue("Generate")
    GENERATE("Generate"),
    @XmlEnumValue("Purge")
    PURGE("Purge"),
    @XmlEnumValue("FreezeOrUnfreeze")
    FREEZE_OR_UNFREEZE("FreezeOrUnfreeze"),
    @XmlEnumValue("Calculate")
    CALCULATE("Calculate"),
    @XmlEnumValue("SaveAndValidate")
    SAVE_AND_VALIDATE("SaveAndValidate"),
    @XmlEnumValue("Reject")
    REJECT("Reject"),
    @XmlEnumValue("Match")
    MATCH("Match"),
    @XmlEnumValue("AddOrSync")
    ADD_OR_SYNC("AddOrSync"),
    @XmlEnumValue("Terminate")
    TERMINATE("Terminate"),
    @XmlEnumValue("Print")
    PRINT("Print"),
    @XmlEnumValue("Associate")
    ASSOCIATE("Associate"),
    @XmlEnumValue("Disassociate")
    DISASSOCIATE("Disassociate"),
    @XmlEnumValue("Regenerate")
    REGENERATE("Regenerate"),
    @XmlEnumValue("Logon")
    LOGON("Logon"),
    @XmlEnumValue("Logoff")
    LOGOFF("Logoff"),
    @XmlEnumValue("Prepare")
    PREPARE("Prepare"),
    @XmlEnumValue("Search")
    SEARCH("Search"),
    @XmlEnumValue("Import")
    IMPORT("Import"),
    @XmlEnumValue("Start")
    START("Start"),
    @XmlEnumValue("Stop")
    STOP("Stop"),
    @XmlEnumValue("Export")
    EXPORT("Export"),
    @XmlEnumValue("Init")
    INIT("Init"),
    @XmlEnumValue("ActivateOrDeactivate")
    ACTIVATE_OR_DEACTIVATE("ActivateOrDeactivate"),
    @XmlEnumValue("Select")
    SELECT("Select"),
    @XmlEnumValue("Undo")
    UNDO("Undo"),
    @XmlEnumValue("UndoAll")
    UNDO_ALL("UndoAll"),
    @XmlEnumValue("RedoAll")
    REDO_ALL("RedoAll"),
    @XmlEnumValue("ApproveSingle")
    APPROVE_SINGLE("ApproveSingle"),
    @XmlEnumValue("UndoCancel")
    UNDO_CANCEL("UndoCancel"),
    @XmlEnumValue("Reallocate")
    REALLOCATE("Reallocate"),
    @XmlEnumValue("Award")
    AWARD("Award"),
    @XmlEnumValue("Resequence")
    RESEQUENCE("Resequence"),
    @XmlEnumValue("List")
    LIST("List"),
    @XmlEnumValue("ValidateAndAdd")
    VALIDATE_AND_ADD("ValidateAndAdd"),
    @XmlEnumValue("SelectAll")
    SELECT_ALL("SelectAll"),
    @XmlEnumValue("Unlock")
    UNLOCK("Unlock"),
    @XmlEnumValue("Activate")
    ACTIVATE("Activate"),
    @XmlEnumValue("Reset")
    RESET("Reset"),
    @XmlEnumValue("BatchCopy")
    BATCH_COPY("BatchCopy"),
    @XmlEnumValue("BatchDelete")
    BATCH_DELETE("BatchDelete"),
    @XmlEnumValue("Review")
    REVIEW("Review"),
    @XmlEnumValue("Extend")
    EXTEND("Extend"),
    @XmlEnumValue("SignOff")
    SIGN_OFF("SignOff"),
    @XmlEnumValue("Isolate")
    ISOLATE("Isolate"),
    @XmlEnumValue("Deisolate")
    DEISOLATE("Deisolate"),
    @XmlEnumValue("Perform")
    PERFORM("Perform"),
    @XmlEnumValue("Complete")
    COMPLETE("Complete"),
    @XmlEnumValue("SetDefault")
    SET_DEFAULT("SetDefault"),
    @XmlEnumValue("Detach")
    DETACH("Detach"),
    @XmlEnumValue("RetrieveSingle")
    RETRIEVE_SINGLE("RetrieveSingle"),
    @XmlEnumValue("Recalculate")
    RECALCULATE("Recalculate"),
    @XmlEnumValue("Quote")
    QUOTE("Quote"),
    @XmlEnumValue("Exclude")
    EXCLUDE("Exclude"),
    @XmlEnumValue("Revoke")
    REVOKE("Revoke"),
    @XmlEnumValue("Lock")
    LOCK("Lock");
    private final String value;

    VERB_Type(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static VERB_Type fromValue(String v) {
        for (VERB_Type c: VERB_Type.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_fields/VERB_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for VERB_Type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="VERB_Type">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="Add"/>
 *     &lt;enumeration value="Get"/>
 *     &lt;enumeration value="Sync"/>
 *     &lt;enumeration value="Delete"/>
 *     &lt;enumeration value="Cancel"/>
 *     &lt;enumeration value="Change"/>
 *     &lt;enumeration value="Confirm"/>
 *     &lt;enumeration value="ConfirmRevert"/>
 *     &lt;enumeration value="ConfirmUpload"/>
 *     &lt;enumeration value="Copy"/>
 *     &lt;enumeration value="Create"/>
 *     &lt;enumeration value="Issue"/>
 *     &lt;enumeration value="Load"/>
 *     &lt;enumeration value="Receive"/>
 *     &lt;enumeration value="Transfer"/>
 *     &lt;enumeration value="Update"/>
 *     &lt;enumeration value="Deactivate"/>
 *     &lt;enumeration value="Approve"/>
 *     &lt;enumeration value="Remove"/>
 *     &lt;enumeration value="Revert"/>
 *     &lt;enumeration value="Replace"/>
 *     &lt;enumeration value="Move"/>
 *     &lt;enumeration value="Validate"/>
 *     &lt;enumeration value="Refresh"/>
 *     &lt;enumeration value="Save"/>
 *     &lt;enumeration value="Upload"/>
 *     &lt;enumeration value="Run"/>
 *     &lt;enumeration value="Download"/>
 *     &lt;enumeration value="GenerateAndRelease"/>
 *     &lt;enumeration value="Process"/>
 *     &lt;enumeration value="Retrieve"/>
 *     &lt;enumeration value="Unlink"/>
 *     &lt;enumeration value="Close"/>
 *     &lt;enumeration value="Assign"/>
 *     &lt;enumeration value="Generate"/>
 *     &lt;enumeration value="Purge"/>
 *     &lt;enumeration value="FreezeOrUnfreeze"/>
 *     &lt;enumeration value="Calculate"/>
 *     &lt;enumeration value="SaveAndValidate"/>
 *     &lt;enumeration value="Reject"/>
 *     &lt;enumeration value="Match"/>
 *     &lt;enumeration value="AddOrSync"/>
 *     &lt;enumeration value="Terminate"/>
 *     &lt;enumeration value="Print"/>
 *     &lt;enumeration value="Associate"/>
 *     &lt;enumeration value="Disassociate"/>
 *     &lt;enumeration value="Regenerate"/>
 *     &lt;enumeration value="Logon"/>
 *     &lt;enumeration value="Logoff"/>
 *     &lt;enumeration value="Prepare"/>
 *     &lt;enumeration value="Search"/>
 *     &lt;enumeration value="Import"/>
 *     &lt;enumeration value="Start"/>
 *     &lt;enumeration value="Stop"/>
 *     &lt;enumeration value="Export"/>
 *     &lt;enumeration value="Init"/>
 *     &lt;enumeration value="ActivateOrDeactivate"/>
 *     &lt;enumeration value="Select"/>
 *     &lt;enumeration value="Undo"/>
 *     &lt;enumeration value="UndoAll"/>
 *     &lt;enumeration value="RedoAll"/>
 *     &lt;enumeration value="ApproveSingle"/>
 *     &lt;enumeration value="UndoCancel"/>
 *     &lt;enumeration value="Reallocate"/>
 *     &lt;enumeration value="Award"/>
 *     &lt;enumeration value="Resequence"/>
 *     &lt;enumeration value="List"/>
 *     &lt;enumeration value="ValidateAndAdd"/>
 *     &lt;enumeration value="SelectAll"/>
 *     &lt;enumeration value="Unlock"/>
 *     &lt;enumeration value="Activate"/>
 *     &lt;enumeration value="Reset"/>
 *     &lt;enumeration value="BatchCopy"/>
 *     &lt;enumeration value="BatchDelete"/>
 *     &lt;enumeration value="Review"/>
 *     &lt;enumeration value="Extend"/>
 *     &lt;enumeration value="SignOff"/>
 *     &lt;enumeration value="Isolate"/>
 *     &lt;enumeration value="Deisolate"/>
 *     &lt;enumeration value="Perform"/>
 *     &lt;enumeration value="Complete"/>
 *     &lt;enumeration value="SetDefault"/>
 *     &lt;enumeration value="Detach"/>
 *     &lt;enumeration value="RetrieveSingle"/>
 *     &lt;enumeration value="Recalculate"/>
 *     &lt;enumeration value="Quote"/>
 *     &lt;enumeration value="Exclude"/>
 *     &lt;enumeration value="Revoke"/>
 *     &lt;enumeration value="Lock"/>
 *     &lt;enumeration value="Acknowledge"/>
 *     &lt;enumeration value="Enable"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "VERB_Type")
@XmlEnum
public enum VERB_Type {

    @XmlEnumValue("Add")
    ADD("Add"),
    @XmlEnumValue("Get")
    GET("Get"),
    @XmlEnumValue("Sync")
    SYNC("Sync"),
    @XmlEnumValue("Delete")
    DELETE("Delete"),
    @XmlEnumValue("Cancel")
    CANCEL("Cancel"),
    @XmlEnumValue("Change")
    CHANGE("Change"),
    @XmlEnumValue("Confirm")
    CONFIRM("Confirm"),
    @XmlEnumValue("ConfirmRevert")
    CONFIRM_REVERT("ConfirmRevert"),
    @XmlEnumValue("ConfirmUpload")
    CONFIRM_UPLOAD("ConfirmUpload"),
    @XmlEnumValue("Copy")
    COPY("Copy"),
    @XmlEnumValue("Create")
    CREATE("Create"),
    @XmlEnumValue("Issue")
    ISSUE("Issue"),
    @XmlEnumValue("Load")
    LOAD("Load"),
    @XmlEnumValue("Receive")
    RECEIVE("Receive"),
    @XmlEnumValue("Transfer")
    TRANSFER("Transfer"),
    @XmlEnumValue("Update")
    UPDATE("Update"),
    @XmlEnumValue("Deactivate")
    DEACTIVATE("Deactivate"),
    @XmlEnumValue("Approve")
    APPROVE("Approve"),
    @XmlEnumValue("Remove")
    REMOVE("Remove"),
    @XmlEnumValue("Revert")
    REVERT("Revert"),
    @XmlEnumValue("Replace")
    REPLACE("Replace"),
    @XmlEnumValue("Move")
    MOVE("Move"),
    @XmlEnumValue("Validate")
    VALIDATE("Validate"),
    @XmlEnumValue("Refresh")
    REFRESH("Refresh"),
    @XmlEnumValue("Save")
    SAVE("Save"),
    @XmlEnumValue("Upload")
    UPLOAD("Upload"),
    @XmlEnumValue("Run")
    RUN("Run"),
    @XmlEnumValue("Download")
    DOWNLOAD("Download"),
    @XmlEnumValue("GenerateAndRelease")
    GENERATE_AND_RELEASE("GenerateAndRelease"),
    @XmlEnumValue("Process")
    PROCESS("Process"),
    @XmlEnumValue("Retrieve")
    RETRIEVE("Retrieve"),
    @XmlEnumValue("Unlink")
    UNLINK("Unlink"),
    @XmlEnumValue("Close")
    CLOSE("Close"),
    @XmlEnumValue("Assign")
    ASSIGN("Assign"),
    @XmlEnumValue("Generate")
    GENERATE("Generate"),
    @XmlEnumValue("Purge")
    PURGE("Purge"),
    @XmlEnumValue("FreezeOrUnfreeze")
    FREEZE_OR_UNFREEZE("FreezeOrUnfreeze"),
    @XmlEnumValue("Calculate")
    CALCULATE("Calculate"),
    @XmlEnumValue("SaveAndValidate")
    SAVE_AND_VALIDATE("SaveAndValidate"),
    @XmlEnumValue("Reject")
    REJECT("Reject"),
    @XmlEnumValue("Match")
    MATCH("Match"),
    @XmlEnumValue("AddOrSync")
    ADD_OR_SYNC("AddOrSync"),
    @XmlEnumValue("Terminate")
    TERMINATE("Terminate"),
    @XmlEnumValue("Print")
    PRINT("Print"),
    @XmlEnumValue("Associate")
    ASSOCIATE("Associate"),
    @XmlEnumValue("Disassociate")
    DISASSOCIATE("Disassociate"),
    @XmlEnumValue("Regenerate")
    REGENERATE("Regenerate"),
    @XmlEnumValue("Logon")
    LOGON("Logon"),
    @XmlEnumValue("Logoff")
    LOGOFF("Logoff"),
    @XmlEnumValue("Prepare")
    PREPARE("Prepare"),
    @XmlEnumValue("Search")
    SEARCH("Search"),
    @XmlEnumValue("Import")
    IMPORT("Import"),
    @XmlEnumValue("Start")
    START("Start"),
    @XmlEnumValue("Stop")
    STOP("Stop"),
    @XmlEnumValue("Export")
    EXPORT("Export"),
    @XmlEnumValue("Init")
    INIT("Init"),
    @XmlEnumValue("ActivateOrDeactivate")
    ACTIVATE_OR_DEACTIVATE("ActivateOrDeactivate"),
    @XmlEnumValue("Select")
    SELECT("Select"),
    @XmlEnumValue("Undo")
    UNDO("Undo"),
    @XmlEnumValue("UndoAll")
    UNDO_ALL("UndoAll"),
    @XmlEnumValue("RedoAll")
    REDO_ALL("RedoAll"),
    @XmlEnumValue("ApproveSingle")
    APPROVE_SINGLE("ApproveSingle"),
    @XmlEnumValue("UndoCancel")
    UNDO_CANCEL("UndoCancel"),
    @XmlEnumValue("Reallocate")
    REALLOCATE("Reallocate"),
    @XmlEnumValue("Award")
    AWARD("Award"),
    @XmlEnumValue("Resequence")
    RESEQUENCE("Resequence"),
    @XmlEnumValue("List")
    LIST("List"),
    @XmlEnumValue("ValidateAndAdd")
    VALIDATE_AND_ADD("ValidateAndAdd"),
    @XmlEnumValue("SelectAll")
    SELECT_ALL("SelectAll"),
    @XmlEnumValue("Unlock")
    UNLOCK("Unlock"),
    @XmlEnumValue("Activate")
    ACTIVATE("Activate"),
    @XmlEnumValue("Reset")
    RESET("Reset"),
    @XmlEnumValue("BatchCopy")
    BATCH_COPY("BatchCopy"),
    @XmlEnumValue("BatchDelete")
    BATCH_DELETE("BatchDelete"),
    @XmlEnumValue("Review")
    REVIEW("Review"),
    @XmlEnumValue("Extend")
    EXTEND("Extend"),
    @XmlEnumValue("SignOff")
    SIGN_OFF("SignOff"),
    @XmlEnumValue("Isolate")
    ISOLATE("Isolate"),
    @XmlEnumValue("Deisolate")
    DEISOLATE("Deisolate"),
    @XmlEnumValue("Perform")
    PERFORM("Perform"),
    @XmlEnumValue("Complete")
    COMPLETE("Complete"),
    @XmlEnumValue("SetDefault")
    SET_DEFAULT("SetDefault"),
    @XmlEnumValue("Detach")
    DETACH("Detach"),
    @XmlEnumValue("RetrieveSingle")
    RETRIEVE_SINGLE("RetrieveSingle"),
    @XmlEnumValue("Recalculate")
    RECALCULATE("Recalculate"),
    @XmlEnumValue("Quote")
    QUOTE("Quote"),
    @XmlEnumValue("Exclude")
    EXCLUDE("Exclude"),
    @XmlEnumValue("Revoke")
    REVOKE("Revoke"),
    @XmlEnumValue("Lock")
    LOCK("Lock"),
    @XmlEnumValue("Acknowledge")
    ACKNOWLEDGE("Acknowledge"),
    @XmlEnumValue("Enable")
    ENABLE("Enable");
    private final String value;

    VERB_Type(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static VERB_Type fromValue(String v) {
        for (VERB_Type c: VERB_Type.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
